aboutsummaryrefslogtreecommitdiff
path: root/planetwars-cli/src/commands/init.rs
diff options
context:
space:
mode:
authorIlion Beyst <ilion.beyst@gmail.com>2021-12-26 22:00:20 +0100
committerIlion Beyst <ilion.beyst@gmail.com>2021-12-26 22:00:20 +0100
commit31b439ee313c9268ac338dd130390d4f7200e693 (patch)
tree75b3905deacdd849d5fb4fab7e28ed3bf366151b /planetwars-cli/src/commands/init.rs
parent0d03a0fbc214dd3fb9a8af562f9d88cccaf5f2c0 (diff)
downloadplanetwars.dev-31b439ee313c9268ac338dd130390d4f7200e693.tar.xz
planetwars.dev-31b439ee313c9268ac338dd130390d4f7200e693.zip
rebrand project to workspace
Diffstat (limited to 'planetwars-cli/src/commands/init.rs')
-rw-r--r--planetwars-cli/src/commands/init.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/planetwars-cli/src/commands/init.rs b/planetwars-cli/src/commands/init.rs
index 42491bc..3c9cf08 100644
--- a/planetwars-cli/src/commands/init.rs
+++ b/planetwars-cli/src/commands/init.rs
@@ -5,7 +5,7 @@ use futures::io;
#[derive(Parser)]
pub struct InitCommand {
/// project root directory
path: String,
}
@@ -29,7 +29,7 @@ impl InitCommand {
std::fs::create_dir_all(path.join("bots/simplebot"))?;
// create files
- copy_asset!(path, "pw_project.toml");
+ copy_asset!(path, "pw_workspace.toml");
copy_asset!(path.join("maps"), "hex.json");
copy_asset!(path.join("bots/simplebot"), "simplebot.py");
@@ -5,7 +5,7 @@ use futures::io;
#[derive(Parser)]
pub struct InitCommand {
- /// project root directory
+ /// workspace root directory
path: String,
}